.. _api-nodes:

vcs.nodes
=========

.. module:: vcs.nodes

Node
----

.. autoclass:: vcs.nodes.Node
   :members:

FileNode
--------

.. autoclass:: vcs.nodes.FileNode
   :members:

RemovedFileNode
---------------

.. autoclass:: vcs.nodes.RemovedFileNode
   :members:

DirNode
-------

.. autoclass:: vcs.nodes.DirNode
   :members:

RootNode
--------

.. autoclass:: vcs.nodes.RootNode
   :members:
